pub struct LibQCryptoProvider { /* private fields */ }Expand description
Main lib-Q cryptographic provider
This provider implements the CryptoProvider trait and delegates to specific operation providers for each cryptographic operation type. It serves as the main entry point for all lib-Q cryptographic operations.
Implementations
Sourceimpl LibQCryptoProvider
impl LibQCryptoProvider
Sourcepub fn kem_provider(&self) -> &LibQKemProvider
pub fn kem_provider(&self) -> &LibQKemProvider
Get the KEM provider
Sourcepub fn signature_provider(&self) -> &LibQSignatureProvider
pub fn signature_provider(&self) -> &LibQSignatureProvider
Get the signature provider
Sourcepub fn hash_provider(&self) -> &LibQHashProvider
pub fn hash_provider(&self) -> &LibQHashProvider
Get the hash provider
Sourcepub fn aead_provider(&self) -> &LibQAeadStubProvider
pub fn aead_provider(&self) -> &LibQAeadStubProvider
Get the stub AEAD provider (use lib-q-aead for real AEAD).